Specifies how the description balloon for placemarks is drawn.
The <bgColor>, if specified, is used as the background color of the
balloon. See <Feature> for a diagram illustrating how the default
description balloon appears in Google Earth.
This is an abstract element and cannot be used directly in a KML file.
It provides elements for specifying the color and color mode of extended
style types.
Information about the copyright holder and any license governing use of this
file. By linking to an appropriate license, you may place your data into the
public domain or grant additional usage rights.
GPX documents contain a metadata header, followed by waypoints, routes, and
tracks. You can add your own elements to the extensions section of the GPX
document.
Specifies how icons for point Placemarks are drawn, both in the Places panel
and in the 3D viewer of Google Earth. The <Icon> element specifies the
icon image. The <scale> element specifies the x, y scaling of the icon.
The color specified in the <color> element of <IconStyle> is blended
with the color of the <Icon>.
Specifies the drawing style (color, color mode, and line width) for all
line geometry. Line geometry includes the outlines of outlined polygons and
the extruded "tether" of Placemark icons (if extrusion is enabled).
Information about the GPX file, author, and copyright restrictions goes in
the metadata section. Providing rich, meaningful information about your GPX
files allows others to search for and use your GPS data.
Specifies the drawing style for all polygons, including polygon extrusions
(which look like the walls of buildings) and line extrusions (which look
like solid fences).
A Track Segment holds a list of Track Points which are logically connected
in order. To represent a single GPS track where GPS reception was lost, or
the GPS receiver was turned off, start a new Track Segment for each
continuous span of track data.